@@ -3,7 +3,6 @@ from glob import glob as _glob
 import functools as _functools
 import tempfile as _tempfile
 
-from six import string_types as _string_types
 import tqdm as _tqdm
 
 # expose these two exceptions as part of the API.  Everything else should feed into these.
@@ -68,7 +67,7 @@ def create(prefix, file_list, out_fn, out_folder=None, **kw):
     if file_list is None:
         file_list = _collect_paths(prefix)
 
-    elif isinstance(file_list, _string_types):
+    elif isinstance(file_list, str):
         try:
             with open(file_list) as f:
                 data = f.readlines()
@@ -104,7 +103,7 @@ def _convert(fn, out_ext, out_folder, **kw):
     out_fn = _os.path.join(out_folder, basename + out_ext)
     errors = ""
     if not _os.path.lexists(out_fn) or ('force' in kw and kw['force']):
-        with _TemporaryDirectory(prefix=out_folder) as tmp:
+        with _TemporaryDirectory(dir=out_folder) as tmp:
             try:
                 extract(fn, dest_dir=tmp)
                 file_list = _collect_paths(tmp)
